<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\DocStoreBundle\Tests\Validator\Constraints;

use Chill\DocStoreBundle\AsyncUpload\SignedUrl;
use Chill\DocStoreBundle\AsyncUpload\TempUrlGeneratorInterface;
use Chill\DocStoreBundle\Entity\StoredObject;
use Chill\DocStoreBundle\Validator\Constraints\AsyncFileExists;
use Chill\DocStoreBundle\Validator\Constraints\AsyncFileExistsValidator;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;
use Symfony\Component\HttpClient\MockHttpClient;
use Symfony\Component\HttpClient\Response\MockResponse;
use Symfony\Component\Validator\Test\ConstraintValidatorTestCase;

/**
 * @internal
 *
 * @coversNothing
 */
class AsyncFileExistsValidatorTest extends ConstraintValidatorTestCase
{
    use ProphecyTrait;

    protected function createValidator()
    {
        $client = new MockHttpClient(function ($method, $url, $options): MockResponse {
            if (str_contains((string) $url, '404')) {
                return new MockResponse('', ['http_code' => 404]);
            }

            return new MockResponse('', ['http_code' => 200]);
        });

        $generator = $this->prophesize(TempUrlGeneratorInterface::class);
        $generator->generate(Argument::in(['GET', 'HEAD']), Argument::type('string'), Argument::any())
            ->will(fn (array $args): SignedUrl => new SignedUrl($args[0], 'https://object.store.example/container/'.$args[1], new \DateTimeImmutable('1 hours')));

        return new AsyncFileExistsValidator($generator->reveal(), $client);
    }

    public function testWhenFileExistsIsValid(): void
    {
        $this->validator->validate((new StoredObject())->setFilename('present'), new AsyncFileExists());

        $this->assertNoViolation();
    }

    public function testWhenFileIsNotPresent(): void
    {
        $this->validator->validate(
            (new StoredObject())->setFilename('is_404'),
            new AsyncFileExists(['message' => 'my_message'])
        );

        $this->buildViolation('my_message')->setParameter('{{ filename }}', 'is_404')->assertRaised();
    }
}
